"use strict";
this.name        = "start_choices"; 
this.author      = "spara"; 
this.copyright   = "2013 - 2014 Mika Spara";
this.licence     = "CC BY-NC-SA 3.0"; 
this.description = "Game start choices"; 
this.version     = "1.6";

this.guiScreenChanged = function(to, from) {
	if (from == "GUI_SCREEN_NEWGAME" && !missionVariables.oolite_tutorial) {
		this.$newGameScreen();
	}
	delete this.guiScreenChanged;
}

this.shipWillLaunchFromStation = function()
{
	player.ship.hudHidden = false;
	delete this.$newGameScreen;
	delete this.$choice;
	delete this.shipWillLaunchFromStation;
}

this.shipLaunchedFromStation = function() {
	if (this.spawnAnacondaToZaonce) {
		system.mainStation.launchShipWithRole("sc_anaconda");
	}
	delete this.shipLaunchedFromStation;
}

this.$newGameScreen = function() {
	this.spawnAnacondaToZaonce = false;
	player.replaceShip("cobra3-player");
	player.credits = 100;
	player.ship.fuel = 100;
	while (player.ship.missiles.length < 3)
		player.ship.awardEquipment("EQ_MISSILE");
	player.ship.removeEquipment("EQ_FUEL_INJECTION");
	player.ship.removeEquipment("EQ_FUEL_SCOOPS");
	player.ship.removeEquipment("EQ_WEAPON_MINING_LASER");
	player.ship.hudHidden = true;
	var options = {
		"1_CLASSIC" : "Classic: Cobra Mk III",
		"2_EASY" : "Fast-track: Cobra Mk III with extra equipment",
		"3_MEDIUM" : "Medium: Cobra Mk I",
		"4_HARD" : "Hard: Adder",
		"5_HARDER" : "Harder: Adder Broke",
		"6_HAULER" : "Hauler: Beaten-up Python",
		"7_MINER" : "Miner: Mining Transporter",
	};		
	mission.runScreen({
		title: "New Game Selection" ,
		message: "Greetings Commander. You are about to start your new career of space flight, combat and trading starting from the space station orbiting the planet Lave. Before embarking you will need to select a starting ship.\n\nBelow are options ranging from the 'Classic' Oolite Start to the more challenging 'Adder Broke' Start. You can examine the choices in detail by selecting them before making your final decision.",
		choices: options,
		model: "coriolis",
		background: "start_choices_bg.png"
	},		
	function (choice)
	{
		if (choice === "1_CLASSIC") this.$choice(1);
		else if (choice === "2_EASY") this.$choice(2);
		else if (choice === "3_MEDIUM") this.$choice(3);
		else if (choice === "4_HARD") this.$choice(4);
		else if (choice === "5_HARDER") this.$choice(5);
		else if (choice === "6_HAULER") this.$choice(6);
		else if (choice === "7_MINER") this.$choice(7);
	});		
}

this.$choice = function(select) {
	player.ship.hudHidden = false;
	switch(select) {
		case 1: //classic start
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Classic Start" ,
				message: "Ship: Cobra Mk III\nSpeed: 0.35 lm\nCargo Space: 20 t\nBase Equipment: Pulse Laser, 3 Missiles\n\Fuel: 7.0 ly\nCredits: "+formatCredits(100, true, true)+"\n\n\"The most successful medium-size ship ever built and a versatile fighter/trader ship.\"",
				choices: options,
				model: "[cobra3-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});					
			break;
		case 2: //easy start
			player.ship.awardEquipment("EQ_FUEL_INJECTION");
			player.ship.awardEquipment("EQ_FUEL_SCOOPS");
			player.ship.aftWeapon = "EQ_WEAPON_MINING_LASER";
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Fast-track Start" ,
				message: "Ship: Cobra Mk III\nSpeed: 0.35 lm\nCargo Space: 20 t\nBase Equipment: Pulse Laser, Mining Laser, 3 Missiles,  Fuel Scoops, Witchspace Fuel Injectors\n\Fuel: 7.0 ly\nCredits: "+formatCredits(100, true, true)+"\n\n* Bounty Hunter: Collect bounties for pirate/fugitive craft destoyed. Capture/rescue escape pods for rewards.\n* Carrier Service: Deliver goods for some-one else and get paid. You can do parcel deliveries right from the start, but for carrier contracts you'll need a ship with larger cargo bays. Find contracts from the interfaces screen.\n* Miner: Blast the asteroids with your mining laser, scoop the fragments and sell the minerals. Aim for the sun to find asteroids.\n* Passenger Service: Carry passengers for profit. You'll need a passenger berth installed to do passenger contracts. Find contracts from the interfaces screen.\n* Trader: Buy low-priced commodities on one world and sell at a higher price on another.",
				choices: options,
				model: "[cobra3-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});					
			break;		
		case 3: //medium start
			player.replaceShip("cobramk1-player");
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Medium Start" ,
				message: "Ship: Cobra Mk I\nSpeed: 0.26 lm\nCargo Space: 10 t\nBase Equipment: Pulse Laser, 1 Missile\n\Fuel: 7.0 ly\nCash: "+formatCredits(100, true, true)+"\n\n\"The first truly effective solo fighter/trader ship, but now superceded by the Mk III.\"",
				choices: options,
				model: "[cobramk1-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});			
			break;
		case 4: //hard start
			player.replaceShip("adder-player");
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Hard Start" ,
				message: "Ship: Adder\nSpeed: 0.24 lm\nCargo Space: 2 t\nBase Equipment: Pulse Laser, 1 Missile, External Heat Shielding\n\Fuel: 7.0 ly\nCash: "+formatCredits(100, true, true)+"\n\n\"An agile and compact ship favored by couriers, customizers and professional racers.\"",
				choices: options,
				model: "[adder-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});			
			break;
		case 5: //harder start
			player.replaceShip("adder-player");
			player.credits = 0;
			player.ship.fuel = 0;
			player.ship.removeEquipment("EQ_HEAT_SHIELD");
			player.ship.removeEquipment("EQ_MISSILE");
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Harder Start" ,
				message: "Ship: Adder\nSpeed: 0.24 lm\nCargo Space: 2 t\nBase Equipment: Pulse Laser\n\Fuel: 0.0 ly\nCash: "+formatCredits(0, true, true)+"\n\n\"An agile and compact ship favored by couriers, customizers and professional racers, although you must find a way to earn credits for fuel, equipment and upgrades.\"",
				choices: options,
				model: "[adder-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});	
			break;
		case 6: //hauler start
			player.replaceShip("python-player");
			player.ship.serviceLevel = 75;
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Hauler Start" ,
				message: "Ship: Python\nSpeed: 0.20 lm\nCargo Space: 100 t\nBase Equipment: Pulse Laser\n\Fuel: 7.0 ly\nCash: "+formatCredits(100, true, true)+"\n\n\"An ageing design that’s still popular with commanders needing a simple robust freighter. She's in a bad shape though, be ready for malfunctions until you can afford a maintenance overhaul.\"",
				choices: options,
				model: "[python-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});	
			break;
		case 7: //miner start
			this.spawnAnacondaToZaonce = true;
			player.replaceShip("sc_transporter-player");
			player.ship.fuel = 0;
			var options = {
				"1_YES" : "Confirm Choice",
				"2_NO" : "Go Back"
			};
			mission.runScreen({
				title: "Miner Start" ,
				message: "Ship: Mining Transporter\nSpeed: 0.1 lm\nCargo Space: 12 t\nBase Equipment: Mining Laser, Fuel Scoops\n\Fuel: 0.0 ly\nCash: "+formatCredits(100, true, true)+"\n\n\"Predating the GCW, this ship serves as shuttle, cargo hauler and industrial platform. Ship has no hyperspace capability. If you want to change system, you'll have to hitchhike through wormhole.\"\n\nLave is a bit rough place to start as a miner, so right after your first launch an Anaconda trader with escorts launches and jumps to Zaonce. You might want to follow...",
				choices: options,
				model: "[sc_transporter-player]",
				background: "start_choices_bg.png"
			},		
			function (choice) {
				if (choice === "2_NO") this.$newGameScreen();
				else this.shipWillLaunchFromStation();
			});	
			break;
	}
}
